<?php
$lang['add_block'] = 'Einen neuen Block hinzuf&uuml;gen';
$lang['advanced_content_copy'] = 'Erweiterte Kopie des Inhalts';
$lang['advanced_copy'] = 'Erweiterte Kopie';
$lang['ask_delete_block'] = 'Wollen Sie diesen Block wirklich l&ouml;schen?';
$lang['ask_really_import'] = 'Wollen Sie diesen Code trotz der obigen Warnung importieren?';
$lang['ask_really_uninstall'] = 'Wollen Sie das wirklich?';
$lang['available_items'] = 'Verf&uuml;gbare Eintr&auml;ge';
$lang['available_templates'] = 'Verf&uuml;gbarer Code';
$lang['blocks'] = 'Bl&ouml;cke';
$lang['blocktype_textinput'] = 'Texteingabe';
$lang['blocktype_textarea'] = 'Textbereich';
$lang['blocktype_dropdown'] = 'Listenfeldmen&uuml;';
$lang['blocktype_checkbox'] = 'Kontrollk&auml;stchen';
$lang['blocktype_file_selector'] = 'Dateiauswahl';
$lang['blocktype_pageselector'] = 'Seitenauswahl';
$lang['blocktype_radiobuttons'] = 'Optionsfelder';
$lang['cancel'] = 'Abbrechen';
$lang['content'] = 'Inhalt';
$lang['contents_of_file'] = 'Gescannte Inhalte und Dateien';
$lang['copy'] = 'Kopieren';
$lang['default_value'] = 'Voreingestellter Wert';
$lang['delete'] = 'L&ouml;schen';
$lang['edit'] = 'Bearbeiten';
$lang['error_broken_xml'] = 'Diese XML-Datei ist ung&uuml;ltig';
$lang['error_copycontent_invalid_name'] = 'Der Titel, der f&uuml;r die Kopie id=%d angegeben wurde, ist ung&uuml;ltig';
$lang['error_copycontent_invalid_menutext'] = 'Der Men&uuml;text, der f&uuml;r die Kopie id=%d angegeben wurde, ist ung&uuml;ltig';
$lang['error_missing_param'] = 'Ein erforderlicher Parameter fehlt oder ist ung&uuml;ltig';
$lang['error_nameexists'] = 'Es existiert bereits ein Eintrag mit diesem Namen';
$lang['error_nocontentselected'] = 'Es wurde kein Inhalt ausgew&auml;hlt';
$lang['error_notfound'] = 'Der Eintrag wurde nicht gefunden';
$lang['error_nothingtoimport'] = 'Diese XML-Datei enth&auml;lt keine Informationen, die in diese Installation importiert werden k&ouml;nnten (weder kompatible Module noch globale Inhaltsbl&ouml;cke oder Benutzerdefinierte Tags)';
$lang['error_nothingselected'] = 'Es wurden keine Eintr&auml;ge ausgew&auml;hlt';
$lang['error_permission_denied'] = 'Zugriff verweigert';
$lang['error_upload'] = 'Das Hochladen der Datei ist fehlgeschlagen';
$lang['error_uploadnotfound'] = 'Die hochgeladene Datei konnte nicht gefunden werden';
$lang['export'] = 'Exportieren';
$lang['export_children'] = 'Untergeordnete Seiten exportieren';
$lang['export_code'] = 'Code exportieren';
$lang['export_content'] = 'Inhalt exportieren';
$lang['extra'] = 'Extra ';
$lang['file'] = 'XML-Datei';
$lang['file_selector'] = 'Dateiauswahl';
$lang['friendlyname'] = 'Calguys Inhalts-Werkzeuge';
$lang['global_content_block'] = 'Globaler Inhaltsblock (GCB)';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This module works in the CMS Made Simple administration console and provides various aditional functions and utilities for working with CMS Made Simple&#039;s content pages.</p>
<h3>Features</h3>
<ul>
  <li>Export content pages to XML</li>
  <li>Import content pages from XML</li>
  <li>Allows Creating and managing various different content blocks for embedding into CMSMS page templates.</li>
  <li>Provides bulk page copy capability.</li>
</ul>
<h3>How do I use it</h3>
<p>If you are an authorized CMS Made Simple web site administrator, and have sufficient privilege to manage all content, then the &quot;Calguys Content Utilities&quot; menu item should appear in the CMS Made Simple administration panel.  You will see a number of tabs, including:</p>
<ul>
  <li><u>Blocks</u>
  <p>This tab provides functionality for creating &quot;named&quot; and managing content blocks of various types.  Tags for these content blocks can then be inserted into CMSMS page templates.  This provides functionality to put additonal content blocks into your page template to allow the user to enter or choose different data which may have a result on the appearance of the page.</p>
  <p>For example, a content block of type &quot;checkbox&quot; could be used to indicate wether an image is to be displayed or not.</p>
  <p>This is an advanced feature, and utilizing this feature requires that you be familiar with the smarty templating engine that is used througout CMSMS.</p>
  </li>
  <li><u>Import</u>
  <p>This tab provides the ability to import one or more content pages from an XML file that was created by the export functionality.   Using this functionality you can easily migrate information from one website to another.<p>
  </li>
  <li><u>Export</u>
  <p>This tab provides the ability to choose a single page from a dropdown to export to XML format.  You can also indicate wether the children of the selected page should be exported.  Clicking on the export button will prompt you to download the XML file.</p>
  <p>The generated XML file does not contain images, or page templates, or global content blocks, etc.  It only contains the contents of the various content objects, and their values.</p>
  </li>
</ul>
<p>Additionally, this module adds a bulk action to the content management page, which should be visible if you have the appropriate permission.  This bulk action allows selecting multiple pages, and creating a single copy of each of the selected pages,</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguy\&#039;s
module homepage at <a href="http://calguy1000.com">calguy1000.com</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org"><calguy1000@cmsmadesimple.org></a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['info_available_items'] = 'W&auml;hlen Sie einen Eintrag aus, um Templates oder Code, die exportiert werden k&ouml;nnen, zu sehen';
$lang['info_blockname'] = 'Verwenden Sie nur alphanumerische Zeichen, Unterstriche (&quot;_&quot;) und Querstriche (&quot;-&quot;)';
$lang['info_blockprompt'] = 'Legen Sie einen menschenlesbaren Prompt fest';
$lang['info_dropdown_options'] = 'Legen Sie hier die Optionen f&uuml;r die Listenfeldmen&uuml;s fest (eine Option pro Zeile). Trennen Sie die Werte f&uuml;r jede Option mit dem Pipe-Zeichen (&quot;|&quot;)';
$lang['info_excludeprefix'] = 'Dateien mit dieser Dateiendung ausschlie&szlig;en (durch Kommata getrennte Liste)';
$lang['info_export_code'] = 'Ausgew&auml;hlte Modul-Templates und Globale Inhaltsbl&ouml;cke f&uuml;r den Einsatz auf einer anderen Webseite in eine XML-Datei exportieren';
$lang['info_filetypes'] = 'Legen Sie hier die Dateierweiterungen fest (durch Kommata getrennt), z.Bsp.: pdf,jpg,doc';
$lang['info_final_import_code'] = 'Die f&uuml;r den Import ausgew&auml;hlten Eintr&auml;ge werden nachfolgend angezeigt. Eintr&auml;ge, die ein &Uuml;berschreibung eines bereits existierenden Eintrages zur Folge haben, sind in <span style=&quot;color: yellow;&quot;>Gelb</span> hervorgehoben. Bitte best&auml;tigen Sie, dass Sie das wirklich m&ouml;chten.<br/><strong>Hinweis:</strong> Wenn Sie an dieser Stelle weitermachen, besteht die M&ouml;glichkeit, dass bereits funktionierende Templates &uuml;berschrieben werden.<br/>
<strong>Hinweis:</strong> Einige Module unterst&uuml;tzen nicht mehrere Templates f&uuml;r jeden Template-Typ. Es kann daher erforderlich sein, dass einige Templates &uuml;berschrieben werden m&uuml;ssen, damit der Import funktioniert.<br/>
<strong>Hinweis:</strong> Dieses Modul nimmt keinerlei Ver&auml;nderungen an den importierten Templates vor, um Referenzen auf Seiten oder Modulaufrufe zu pr&uuml;fen. Sie m&uuml;ssen daher anschlie&szlig;end jedes Template individuell an die Bed&uuml;rftnisse der Webseite anpassen.';
$lang['info_import_code'] = 'Den Import der ausgew&auml;hlten Globalen Inhaltsbl&ouml;cke, Benutzerdefinierten Tags und Modul-Templates aus einer XML-Datei erlauben.<br/><strong>Hinweis:</strong> Dies ist eine Funktion f&uuml;r fortgeschrittene Anwender. Damit k&ouml;nnen die Templates einer existierenden Seite &uuml;berschrieben werden. Verwenden Sie diese Funktion daher mit Vorsicht!';
$lang['info_scanned_file'] = 'Sie finden im folgenden die eingelesenen Inhalte der angegebenen XML-Datei. Sie k&ouml;nnen sich eine Vorschau der Eintr&auml;ge ansehen und einige f&uuml;r den Import ausw&auml;hlen. Au&szlig;erdem k&ouml;nnen Sie optional einen neuen Namen f&uuml;r die importierten Templates festlegen.';
$lang['import'] = 'Importieren';
$lang['import_code'] = 'Code importieren';
$lang['import_content'] = 'Inhalt importieren';
$lang['import_name'] = 'Name importieren';
$lang['list_gcbs'] = 'Globale Inhaltsbl&ouml;cke';
$lang['list_udts'] = 'Benutzerdefinierte Tags';
$lang['moddescription'] = 'Ein Modul mit Werkzeugen f&uuml;r die Unterst&uuml;tzung der Verwaltung von Inhalten';
$lang['module'] = 'Modul';
$lang['modules'] = 'Module';
$lang['module_template'] = 'Modul-Template';
$lang['msg_blockadded'] = 'Der Block wurde erfolgreich hinzugef&uuml;gt';
$lang['msg_blockupdated'] = 'Die Werte des Blocks wurden aktualisiert';
$lang['msg_cancelled'] = 'Die Operation wurde abgebrochen';
$lang['msg_imported'] = '%d Eintr&auml;ge aus der XML-Datei importiert';
$lang['name'] = 'Name ';
$lang['new_alias'] = 'Neuer Seiten-Alias';
$lang['new_menutext'] = 'Neuer Men&uuml;text';
$lang['new_name'] = 'Neuer Name';
$lang['new_parent'] = 'Neue &uuml;bergeordnete Seite';
$lang['next'] = 'N&auml;chste';
$lang['parent'] = '&Uuml;bergeordnete Seite';
$lang['postinstall'] = 'Das CGContentUtils-Modul wurde installiert';
$lang['postuninstall'] = 'Das CGContentUtils-Modul wurde deinstalliert';
$lang['preview'] = 'Vorschau';
$lang['prompt'] = 'Prompt ';
$lang['prompt_cols'] = 'Spalten';
$lang['prompt_dir'] = 'Verzeichnis <em>(relativ zum /uploads-Ordner)</em>';
$lang['prompt_excludeprefix'] = 'Dateien mit dieser Dateiendung ausschlie&szlig;en';
$lang['prompt_filetypes'] = 'Erlaubte Dateitypen';
$lang['prompt_length'] = 'L&auml;nge';
$lang['prompt_maxlength'] = 'Maximale L&auml;nge';
$lang['prompt_options'] = 'Optionen';
$lang['prompt_page'] = 'Seite';
$lang['prompt_recurse'] = 'Rekursiv in Unterverzeichnisse';
$lang['prompt_rows'] = 'Zeilen';
$lang['prompt_sortfiles'] = 'Dateien nach Namen sortieren';
$lang['prompt_value'] = 'Wert';
$lang['scan'] = 'Scannen';
$lang['select_all'] = 'Alle ausw&auml;hlen';
$lang['start_page'] = 'Startseite';
$lang['submit'] = 'Absenden';
$lang['type'] = 'Typ';
$lang['usage'] = 'Verwendung';
$lang['userdefined_tag'] = 'Benutzerdefinierter Tag (UDT)';
$lang['xml_file'] = 'XML-Datei';
$lang['utma'] = '156861353.1865716571.1334693985.1334693985.1334779289.2';
$lang['utmz'] = '156861353.1334693985.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>